@@ -14,6 +14,7 @@ import random
 from statistics import mean
 from typing import Iterator, List, Tuple, Callable
 
+import numpy as np
 import toolz
 from toolz import curry
 
@@ -72,6 +73,7 @@ def iteriter_op(f):
 
     :param f function: the function to wrap
     """
+
     @wraps(f)
     def typecheck_f(next_individual: Iterator, *args, **kwargs) -> Iterator:
         if not isinstance(next_individual, collections.abc.Iterator):
@@ -103,6 +105,7 @@ def listlist_op(f):
 
     :param f function: the function to wrap
     """
+
     @wraps(f)
     def typecheck_f(population: List, *args, **kwargs) -> List:
         if not isinstance(population, list):
@@ -134,6 +137,7 @@ def listiter_op(f):
 
     :param f function: the function to wrap
     """
+
     @wraps(f)
     def typecheck_f(population: List, *args, **kwargs) -> Iterator:
         if not isinstance(population, list):
@@ -165,6 +169,7 @@ def iterlist_op(f):
 
     :param f function: the function to wrap
     """
+
     @wraps(f)
     def typecheck_f(next_individual: Iterator, *args, **kwargs) -> List:
         if not isinstance(next_individual, collections.abc.Iterator):
@@ -289,6 +294,7 @@ def uniform_crossover(next_individual: Iterator,
     :param p_swap: how likely are we to swap each pair of genes
     :return: two recombined individuals
     """
+
     def _uniform_crossover(ind1, ind2, p_swap):
         """ Recombination operator that can potentially swap any matching pair of
         genes between two individuals with some probability.
@@ -329,7 +335,8 @@ def uniform_crossover(next_individual: Iterator,
 @curry
 @iteriter_op
 def n_ary_crossover(next_individual: Iterator,
-                    num_points: int = 1) -> Iterator:
+                    num_points: int = 1,
+                    p=1.0) -> Iterator:
     """ Do crossover between individuals between N crossover points.
 
     1 < n < genome length - 1
@@ -351,6 +358,7 @@ def n_ary_crossover(next_individual: Iterator,
     :param num_points: how many crossing points do we allow?
     :return: two recombined
     """
+
     def _pick_crossover_points(num_points, genome_size):
         """
         Randomly choose (without replacement) crossover points.
@@ -364,18 +372,16 @@ def n_ary_crossover(next_individual: Iterator,
         return xpts
 
     def _n_ary_crossover(child1, child2, num_points):
-        # Sanity checks
-        if len(child1.genome) != len(child2.genome):
-            raise RuntimeError('Invalid length for n_ary_crossover')
-        elif len(child1.genome) < num_points + 1:
+        if len(child1.genome) < num_points  or \
+           len(child2.genome) < num_points :
             raise RuntimeError(
                 'Invalid number of crossover points for n_ary_crossover')
 
         children = [child1, child2]
-        genome1 = child1.genome[0:0]  # empty sequence - maintain type
+        genome1 = child1.genome[0:0]  # empty test_sequence - maintain type
         genome2 = child2.genome[0:0]
 
-        # Used to toggle which sub-sequence is copied between offspring
+        # Used to toggle which sub-test_sequence is copied between offspring
         src1, src2 = 0, 1
 
         # Pick crossover points
@@ -397,11 +403,14 @@ def n_ary_crossover(next_individual: Iterator,
         parent1 = next(next_individual)
         parent2 = next(next_individual)
 
-        child1, child2 = _n_ary_crossover(parent1, parent2, num_points)
-
-        yield child1
-        yield child2
-
+        # Return the parents unmodified if we're not performing crossover
+        if np.random.uniform() > p:
+            yield parent1
+            yield parent2
+        else:  # Else cross them over
+            child1, child2 = _n_ary_crossover(parent1, parent2, num_points)
+            yield child1
+            yield child2
 
 
 ##############################
@@ -409,7 +418,8 @@ def n_ary_crossover(next_individual: Iterator,
 ##############################
 @curry
 @listlist_op
-def truncation_selection(offspring: List, size: int, parents: List = None) -> List:
+def truncation_selection(offspring: List, size: int,
+                         parents: List = None) -> List:
     """ return the `size` best individuals from the given population
 
         This defaults to (mu, lambda) if `parents` is not given.
@@ -510,7 +520,8 @@ def insertion_selection(offspring: List, parents: List) -> List:
     for child in offspring:
         selected_parent_index = random.randrange(len(copied_parents))
         copied_parents[selected_parent_index] = max(child,
-                                                    copied_parents[selected_parent_index])
+                                                    copied_parents[
+                                                        selected_parent_index])
 
         return copied_parents
 
@@ -521,7 +532,7 @@ def insertion_selection(offspring: List, parents: List) -> List:
 @curry
 @listiter_op
 def naive_cyclic_selection(population: List) -> Iterator:
-    """ Deterministically returns individuals, and repeats the same sequence
+    """ Deterministically returns individuals, and repeats the same test_sequence
     when exhausted.
 
     This is "naive" because it doesn't shuffle the population between complete
@@ -551,7 +562,7 @@ def naive_cyclic_selection(population: List) -> Iterator:
 @listiter_op
 def cyclic_selection(population: List) -> Iterator:
     """ Deterministically returns individuals in order, then shuffles the
-    sequence, returns the individuals in that new order, and repeats this
+    test_sequence, returns the individuals in that new order, and repeats this
     process.
 
     >>> from leap_ec.individual import Individual
@@ -566,13 +577,13 @@ def cyclic_selection(population: List) -> Iterator:
     :return: the next selected individual
     """
     # this is essentially itertools.cycle() that just shuffles
-    # the saved sequence between cycles.
+    # the saved test_sequence between cycles.
     saved = []
     for individual in population:
         yield individual
         saved.append(individual)
     while saved:
-        # randomize the sequence between cycles to remove this source of sample
+        # randomize the test_sequence between cycles to remove this source of sample
         # bias
         random.shuffle(saved)
         for individual in saved:
@@ -630,8 +641,7 @@ def pool(next_individual: Iterator, size: int) -> List:
 # Function migrate
 ##############################
 def migrate(context, topology, emigrant_selector,
-            replacement_selector, migration_gap):
-
+            replacement_selector, migration_gap, customs_stamp=lambda x, _: x):
     num_islands = topology.number_of_nodes()
 
     # We wrap a closure around some persistent state to keep trag of
@@ -644,6 +654,11 @@ def migrate(context, topology, emigrant_selector,
 
         # Immigration
         for imm in immigrants[current_subpop]:
+            # Do island-specific transformation
+            # For example, this callback might update the individuals 'problem'
+            # field to point to a new fitness function for the island, and
+            # re-evalute its fitness.
+            imm = customs_stamp(imm, current_subpop)
             # Compete for a place in the new population
             contestant = next(replacement_selector(population))
             if imm > contestant:
@@ -668,6 +683,9 @@ def migrate(context, topology, emigrant_selector,
             dest = random.choice(list(neighbors))
             # Add the emigrant to its immigration list
             immigrants[dest].append(emi)
+            # FIXME In a heterogeneous island model, we also need to
+            # set the emigrant's decoder and/or problem to match the
+            # new islan'ds decoder and/or problem.
 
         return population
 
@@ -764,44 +782,49 @@ class CooperativeEvaluate(Operator):
                 # Select a fellow collaborator from the other subpopulations
                 ind = next(selectors[i])
                 # Make sure we actually got something with a genome back
-                assert(hasattr(ind, 'genome'))
+                assert (hasattr(ind, 'genome'))
                 collaborators.append(ind)
             else:
                 # Stick this subpop's individual in as-is
                 collaborators.append(current_ind)
 
-        assert(len(collaborators) == len(subpopulations))
+        assert (len(collaborators) == len(subpopulations))
         return collaborators
 
     @staticmethod
     def _log_trial(writer, context, collaborators, combined_ind, trial_id):
         """Record information about a batch of collaborators to a CSV writer."""
         for i, collab in enumerate(collaborators):
-            writer.writerow({'generation': context['leap']['generation'],
-                             'subpopulation': context['leap']['current_subpopulation'],
-                             'individual_type': 'Collaborator',
+            writer.writerow({'generation'                : context['leap'][
+                'generation'],
+                             'subpopulation'             : context['leap'][
+                                 'current_subpopulation'],
+                             'individual_type'           : 'Collaborator',
                              'collaborator_subpopulation': i,
-                             'genome': collab.genome,
-                             'fitness': collab.fitness})
+                             'genome'                    : collab.genome,
+                             'fitness'                   : collab.fitness})
 
-        writer.writerow({'generation': context['leap']['generation'],
-                         'subpopulation': context['leap']['current_subpopulation'],
-                         'individual_type': 'Combined Individual',
+        writer.writerow({'generation'                : context['leap'][
+            'generation'],
+                         'subpopulation'             : context['leap'][
+                             'current_subpopulation'],
+                         'individual_type'           : 'Combined Individual',
                          'collaborator_subpopulation': None,
-                         'genome': combined_ind.genome,
-                         'fitness': combined_ind.fitness})
+                         'genome'                    : combined_ind.genome,
+                         'fitness'                   : combined_ind.fitness})
 
 
 ##############################
 # function compute_expected_probability
 ##############################
-def compute_expected_probability(expected: float, individual_genome: List) \
+def compute_expected_probability(expected_num_mutations: float,
+                                 individual_genome: List) \
         -> float:
     """ Computed the probability of mutation based on the desired average
     expected mutation and genome length.
 
-    :param expected: times individual is to be mutated on average
+    :param expected_num_mutations: times individual is to be mutated on average
     :param individual_genome: genome for which to compute the probability
     :return: the corresponding probability of mutation
     """
-    return 1.0 / len(individual_genome) * expected
+    return 1.0 / len(individual_genome) * expected_num_mutations
