@@ -1,17 +1,16 @@
 """
     Unit tests for inc_generation()
 """
-
-from leap_ec import core, util
-
+from leap_ec.context import context
+from leap_ec.util import inc_generation
 
 def test_inc_generation():
     """ Test the inc_generation() function.
     """
-    my_inc_generation = util.inc_generation(core.context)
+    my_inc_generation = inc_generation(context)
 
     # The core context is set to the current generation, which will start as zero
-    assert core.context['leap']['generation'] == 0
+    assert context['leap']['generation'] == 0
 
     # We can also directly query the internal state of the generation incrementer
     assert my_inc_generation.generation() == 0
@@ -23,7 +22,7 @@ def test_inc_generation():
     assert curr_generation == 1
 
     # The core context state should have updated
-    assert core.context['leap']['generation'] == 1
+    assert context['leap']['generation'] == 1
 
     # And, of course, the internal state will reflect that reality, too
     assert my_inc_generation.generation() == 1
@@ -35,7 +34,7 @@ def test_inc_generation_callbacks():
     def callback(new_generation):
         assert new_generation == 1
 
-    my_inc_generation = util.inc_generation(core.context, callbacks=[callback])
+    my_inc_generation = inc_generation(context, callbacks=[callback])
 
     # Incremented the generation should call our test callback
     my_inc_generation()
